from lupin import Mapper, Schema, fields as f
from models import Artist

mapper = Mapper()

mapping = mapper.register(Artist, Schema({
    "name": f.String(),
    "birthDate": f.DateTime(binding="birth_date", format="%Y-%m-%d")
}))

data = {
    "name": "Leonardo da Vinci"
}

artist = mapper.load(data, mapping, allow_partial=True)
assert artist.name == "Leonardo da Vinci"
assert not hasattr(artist, "birth_date")



import pytest

from lupin.fields import Int
from lupin.errors import InvalidType


@pytest.fixture
def field():
    return Int()


class TestValidate(object):
    def test_raises_error_if_not_an_int(self, field):
        with pytest.raises(InvalidType):
            field.validate("46", [])

    def test_does_nothing_if_int(self, field):
        field.validate(46, [])
